@@ -52,11 +52,11 @@ def search_bible(request:str) -> str:
         output = f"""# Search for `{search_string}`
 
 
-## Exact Matches ({len(exact_matches)} verse(s))
+## Exact Matches [{len(exact_matches)} verse(s)]
 
 {"- " if semantic_matches else ""}{"\n- ".join(exact_matches)}
 
-## Semantic Matches ({len(semantic_matches)} verse(s))
+## Semantic Matches [{len(semantic_matches)} verse(s)]
 
 {"- " if semantic_matches else ""}{"\n- ".join(semantic_matches) if semantic_matches else "[`Ollama` is not found! BibleMate AI uses `Ollama` to generate embeddings for semantic searches. You may install it from https://ollama.com/ so that you can perform semantic searches of the Bible with BibleMate AI.]"}"""
         return output
@@ -85,28 +85,42 @@ def retrieve_bible_cross_references(request:str) -> str:
 
 @mcp.tool
 def retrieve_pointed_hebrew_or_accented_greek_bible_verses(request:str) -> str:
-    """retrieve Hebrew (with pointed vowels) or Greek (with accents) Bible verses; bible verse reference(s) must be given"""
+    """retrieve Hebrew (with pointed vowels) or Greek (with accents) Bible verses; bible verse reference(s) must be given, e.g. John 3:16-17; single or multiple references accepted, e.g. Deut 6:4; Gen 1:26-27"""
     global agentmake, getResponse
     messages = agentmake(request, **{'tool': 'uba/ohgb'}, **AGENTMAKE_CONFIG)
     return getResponse(messages)
 
 @mcp.tool
 def retrieve_hebrew_or_greek_bible_verses(request:str) -> str:
-    """retrieve Hebrew (without pointed vowels) or Greek (without accents) Bible verses; bible verse reference(s) must be given"""
+    """retrieve Hebrew (without pointed vowels) or Greek (without accents) Bible verses; bible verse reference(s) must be given, e.g. John 3:16-17; single or multiple references accepted, e.g. Deut 6:4; Gen 1:26-27"""
     global agentmake, getResponse
     messages = agentmake(request, **{'tool': 'uba/mob'}, **AGENTMAKE_CONFIG)
     return getResponse(messages)
 
 @mcp.tool
 def retrieve_english_bible_verses(request:str) -> str:
-    """retrieve English Bible verses; bible verse reference(s) must be given, e.g. John 3:16-17; multiple references accepted, e.g. John 3:16; Deut 6:4"""
+    """retrieve English Bible verses; bible verse reference(s) must be given, e.g. John 3:16-17; single or multiple references accepted, e.g. Deut 6:4; Gen 1:26-27"""
     global agentmake, getResponse
     messages = agentmake(request, **{'tool': 'uba/net'}, **AGENTMAKE_CONFIG)
     return getResponse(messages)
 
 @mcp.tool
 def retrieve_english_bible_chapter(request:str) -> str:
-    """retrieve English Bible chapter, a whole chapter; bible chapter reference must be given, e.g. John 3"""
+    """retrieve a whole English Bible chapter; bible chapter reference must be given, e.g. John 3"""
+    global agentmake, getResponse
+    messages = agentmake(request, **{'tool': 'uba/net_chapter'}, **AGENTMAKE_CONFIG)
+    return getResponse(messages)
+
+@mcp.tool
+def retrieve_chinese_bible_verses(request:str) -> str:
+    """retrieve Chinese Bible verses; bible verse reference(s) must be given, e.g. John 3:16-17; single or multiple references accepted, e.g. Deut 6:4; Gen 1:26-27"""
+    global agentmake, getResponse
+    messages = agentmake(request, **{'tool': 'uba/cuv'}, **AGENTMAKE_CONFIG)
+    return getResponse(messages)
+
+@mcp.tool
+def retrieve_chinese_bible_chapter(request:str) -> str:
+    """retrieve a whole Chinese Bible chapter; bible chapter reference must be given, e.g. John 3"""
     global agentmake, getResponse
     messages = agentmake(request, **{'tool': 'uba/net_chapter'}, **AGENTMAKE_CONFIG)
     return getResponse(messages)
@@ -118,13 +132,6 @@ def read_bible_commentary(request:str) -> str:
     messages = agentmake(request, **{'tool': 'uba/ai_comment'}, **AGENTMAKE_CONFIG)
     return getResponse(messages)
 
-@mcp.tool
-def retrieve_chinese_bible_verses(request:str) -> str:
-    """retrieve Chinese Bible verses; bible verse reference(s) must be given"""
-    global agentmake, getResponse
-    messages = agentmake(request, **{'tool': 'uba/cuv'}, **AGENTMAKE_CONFIG)
-    return getResponse(messages)
-
 @mcp.tool
 def refine_bible_translation(request:str) -> str:
     """refine the translation of a Bible verse or passage"""
