@@ -11,9 +11,12 @@ class BibleVectorDatabase:
     Sqlite Vector Database via `apsw`
     https://rogerbinns.github.io/apsw/pysqlite.html
 
+    Requirement: Install `Ollama` separately
+
     ```usage
     from biblemate.core.bible_db import BibleVectorDatabase
     db = BibleVectorDatabase('my_bible.bible') # edit 'my_bible.bible' to your bible file path
+    db.add_vectors() # add vectors to the database
     results = db.search_meaning("Jesus love", 10)
     ```
     """
